@@ -1,9 +1,9 @@
 package Sah::Schema::currency::pair;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-02'; # DATE
+our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Sah-Schemas-Currency'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 our $schema = [str => {
     summary => 'Fiat currency pair, e.g. USD/IDR',
@@ -22,11 +22,11 @@ _
     #'x.completion' => 'currency_pair',
     'x.perl.coerce_rules' => ['From_str::to_currency_pair'],
     examples => [
-        {data=>'', valid=>0},
-        {data=>'idr', valid=>0},
-        {data=>'usd/idr', valid=>1, res=>'USD/IDR'},
-        {data=>'usd idr', valid=>0},
-        {data=>'usd/foo', valid=>0},
+        {value=>'', valid=>0},
+        {value=>'idr', valid=>0},
+        {value=>'usd/idr', valid=>1, res=>'USD/IDR'},
+        {value=>'usd idr', valid=>0},
+        {value=>'usd/foo', valid=>0},
     ],
 }, {}];
 
@@ -45,21 +45,51 @@ Sah::Schema::currency::pair - Fiat currency pair, e.g. USD/IDR
 
 =head1 VERSION
 
-This document describes version 0.005 of Sah::Schema::currency::pair (from Perl distribution Sah-Schemas-Currency), released on 2020-03-02.
+This document describes version 0.006 of Sah::Schema::currency::pair (from Perl distribution Sah-Schemas-Currency), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
+Using with L<Data::Sah>:
+
+ use Data::Sah qw(gen_validator);
+ my $vdr = gen_validator("currency::pair*");
+ say $vdr->($data) ? "valid" : "INVALID!";
+
+ # Data::Sah can also create a validator to return error message, coerced value,
+ # even validators in other languages like JavaScript, from the same schema.
+ # See its documentation for more details.
+
+Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+
+ package MyApp;
+ our %SPEC;
+ $SPEC{myfunc} = {
+     v => 1.1,
+     summary => 'Routine to do blah ...',
+     args => {
+         arg1 => {
+             summary => 'The blah blah argument',
+             schema => ['currency::pair*'],
+         },
+         ...
+     },
+ };
+ sub myfunc {
+     my %args = @_;
+     ...
+ }
+
 Sample data:
 
- ""  # INVALID
+ undef  # INVALID
 
- "idr"  # INVALID
+ undef  # INVALID
 
- "usd/idr"  # valid, becomes "USD/IDR"
+ undef  # valid, becomes "USD/IDR"
 
- "usd idr"  # INVALID
+ undef  # INVALID
 
- "usd/foo"  # INVALID
+ undef  # INVALID
 
 =head1 DESCRIPTION
 
